@@ -97,11 +97,11 @@ class DataFrame:
         else:
             nltk.download('stopwords')
             stopwords = nltk.corpus.stopwords.words(language_or_stopwords_list)
-        self.transform_column(column, column, DataFrame.remove_stopwords, True, stopwords)
+        self.transform_column(column, column, DataFrame.remove_stopwords_lambda, True, stopwords)
         return self.__dataframe
     
     @staticmethod
-    def remove_stopwords(document, stopwords_list):
+    def remove_stopwords_lambda(document, stopwords_list):
         stopwords = stopwords_list
         words = word_tokenize(document)
         for w in words:
